import os
import re

def shorten_folder_name(name, max_length=8):
    name = re.sub(r'[^a-zA-Z0-9]', '', name).upper()
    
    if len(name) <= max_length:
        return name
    
    words = name.split()
    if len(words) > 1:
        short_name = ''
        for word in words:
            if len(short_name) < max_length - 1:
                short_name += word[0]
        remaining = max_length - len(short_name)
        if remaining > 0:
            short_name += words[-1][1:remaining + 1]
        return short_name[:max_length]
    
    return name[:max_length]

def rename_folders(source_dir):
    if not os.path.exists(source_dir):
        print(f"Error: The directory '{source_dir}' does not exist.")
        input("Press ENTER to exit...")
        return
    
    folders = [f for f in os.listdir(source_dir) if os.path.isdir(os.path.join(source_dir, f))]
    
    if not folders:
        print(f"Warning: No folders found '{source_dir}'.")
        input("Press ENTER to exit...")
        return
    
    used_names = {}
    
    for folder in folders:
        short_name = shorten_folder_name(folder)
        
        base_name = short_name
        counter = 1
        while short_name in used_names:
            short_name = f"{base_name[:6]}~{counter}"
            counter += 1
        
        used_names[short_name] = folder
        
        old_path = os.path.join(source_dir, folder)
        new_path = os.path.join(source_dir, short_name)
        try:
            os.rename(old_path, new_path)
            print(f"Renamed: {folder} -> {short_name}")
        except Exception as e:
            print(f"Rename Error {folder}: {e}")

def main():
    print("=== Folder Renamer for MS-DOS by n4tive ===")
    print("This program renames folders to short (8.3) names compatible with MS-DOS.")
    source_directory = input("Enter the directory where the game folders are located (e.g., E:\\DosGames): ")
    source_directory = source_directory.replace('/', '\\')
    rename_folders(source_directory)
    print("\nProcess finished.")
    input("Press ENTER to exit...")

if __name__ == "__main__":
    main()